## classical_music.tl.db
### media (22369 rows)
|   id | path                                        |   size | time_created   |   duration |   play_count |   time_last_played | language   | tags   | ie_key   | title                                                                                       |   view_count | width   | height   |   fps | average_rating   | live_status   | age_limit   | playlist_path                                             | uploader   | is_deleted   | is_downloaded   | time_uploaded   | time_modified   |   time_deleted | time_downloaded   | extractor_id   |
|------|---------------------------------------------|--------|----------------|------------|--------------|---------------|------------|--------|----------|---------------------------------------------------------------------------------------------|--------------|---------|----------|-------|------------------|---------------|-------------|-----------------------------------------------------------|------------|--------------|-----------------|-----------------|-----------------|----------------|-------------------|----------------|
|    1 | https://www.youtube.com/watch?v=yDrk4x0oClU |      0 |                |        213 |            0 |             0 |            |        | Youtube  | Atlas del arte español (Aitor Merino Martínez) - Sala Mauro Muriedas (Torrelavega)          |          118 |         |          |     0 |                  |               |             | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos |            |              |                 |                 |                 |              0 |                   | yDrk4x0oClU    |
|    2 | https://www.youtube.com/watch?v=f1uTf4uxjhQ |      0 |                |       1785 |            0 |             0 |            |        | Youtube  | Carmen Barradas y Néffer Kröger: La iniciativa particular en la conservación del patrimonio |          212 |         |          |     0 |                  |               |             | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos |            |              |                 |                 |                 |              0 |                   | f1uTf4uxjhQ    |
|    3 | https://www.youtube.com/watch?v=5NcLJGBOuNk |      0 |                |        364 |            0 |             0 |            |        | Youtube  | El viaje a través de su dimensión sonora: Juan Muñoz e Isidoro Valcárcel Medina             |           71 |         |          |     0 |                  |               |             | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos |            |              |                 |                 |                 |              0 |                   | 5NcLJGBOuNk    |
|    4 | https://www.youtube.com/watch?v=_h-tMDaPMyU |      0 |                |        983 |            0 |             0 |            |        | Youtube  | La conservación del patrimonio sonoro inmaterial: El proyecto ASOMA como caso de estudio    |          114 |         |          |     0 |                  |               |             | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos |            |              |                 |                 |                 |              0 |                   | _h-tMDaPMyU    |
|    5 | https://www.youtube.com/watch?v=UG5Gucedr44 |      0 |                |         99 |            0 |             0 |            |        | Youtube  | Atlas del arte español (Colección Aitor Merino Martínez) - O Vello Cárcere (Lugo)           |           93 |         |          |     0 |                  |               |             | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos |            |              |                 |                 |                 |              0 |                   | UG5Gucedr44    |

### playlists (63 rows)
|   id | extractor_key   | title                             | path                                                      | uploader                 | yt_dlp_config   | dl_config   |   is_deleted | category   | profile   |   time_deleted | extractor_playlist_id    |
|------|-----------------|-----------------------------------|-----------------------------------------------------------|--------------------------|-----------------|-------------|--------------|------------|-----------|----------------|--------------------------|
|    1 | Youtube         | Aitor Merino Martínez - Videos    | https://www.youtube.com/c/AitorMerinoMart%C3%ADnez/videos | UC6hedNNZ1nvVO0mXeAzwhkw | {}              | {}          |            0 | Youtube    | video     |              0 | UC6hedNNZ1nvVO0mXeAzwhkw |
|    2 | Youtube         | bigfootpegrande - Videos          | https://www.youtube.com/c/bigfootpegrande/videos          | UCljUaQQtfaRWh0LmZKm8CZw | {}              | {}          |              | Youtube    | video     |              0 | UCljUaQQtfaRWh0LmZKm8CZw |
|    3 | Youtube         | Guitaryuya - Videos               | https://www.youtube.com/c/Guitaryuya/videos               | UCFINSHYSVqKysIzHh4OB6BA | {}              | {}          |              | Youtube    | video     |              0 | UCFINSHYSVqKysIzHh4OB6BA |
|    4 | Youtube         | Htet Arkar - Videos               | https://www.youtube.com/c/HtetArkarOfficial/videos        | UCRGmI4AI0Gz0BdDa8Mw51tg | {}              | {}          |              | Youtube    | video     |              0 | UCRGmI4AI0Gz0BdDa8Mw51tg |
|    5 | Youtube         | Instrumental Sesc Brasil - Videos | https://www.youtube.com/c/InstrumentalSescBrasil/videos   | UCAvVsLvggnn7KnDRJ9Iv6mQ | {}              | {}          |              | Youtube    | video     |              0 | UCAvVsLvggnn7KnDRJ9Iv6mQ |


## flow.db
### sqlite_stat1 (0 rows)
| tbl   | idx   | stat   |
|-------|-------|--------|

### media_new_7040b8c4e687 (0 rows)
| size   | duration   | time_created   | time_modified   | time_deleted   | time_downloaded   | play_count   | time_last_played   | fps   | view_count   | path   | id   | ie_key   | playlist_path   | title   | uploader   | tags   |
|--------|------------|----------------|-----------------|----------------|-------------------|--------------|---------------|-------|--------------|--------|------|----------|-----------------|---------|------------|--------|

### media (278466 rows)
|   id |   size |   duration |   time_created |   time_modified |   time_deleted |   time_downloaded |   play_count |   time_last_played |   fps | view_count   | path                                                                                             | ie_key   | playlist_path                                              | title                              | uploader                 | tags   |   extractor_id |
|------|--------|------------|----------------|-----------------|----------------|-------------------|--------------|---------------|-------|--------------|--------------------------------------------------------------------------------------------------|----------|------------------------------------------------------------|------------------------------------|--------------------------|--------|----------------|
|    1 |      0 |        137 |     1668896685 |               0 |              0 |                 0 |            0 |             0 |     0 |              | https://www.youtube.com/watch?v=wfElkQhOjLI#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D | Youtube  | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | The First Noél                     | UC84nV7P2Ptlv7GKB-wQOBnA |        |              1 |
|    2 |      0 |        171 |     1668896685 |               0 |              0 |                 0 |            0 |             0 |     0 |              | https://www.youtube.com/watch?v=gRxPR7hCTgQ#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D | Youtube  | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | God Rest Ye Merry Gentlemen Fantsy | UC84nV7P2Ptlv7GKB-wQOBnA |        |              2 |
|    3 |      0 |        113 |     1668896685 |               0 |              0 |                 0 |            0 |             0 |     0 |              | https://www.youtube.com/watch?v=TFZmAnZA1rU#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D | Youtube  | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | We Three Kings                     | UC84nV7P2Ptlv7GKB-wQOBnA |        |              3 |
|    4 |      0 |        136 |     1668896685 |               0 |              0 |                 0 |            0 |             0 |     0 |              | https://www.youtube.com/watch?v=YeAAoi-4Gq8#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D | Youtube  | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | The Bells of St. Mary's            | UC84nV7P2Ptlv7GKB-wQOBnA |        |              4 |
|    5 |      0 |         72 |     1668896685 |               0 |              0 |                 0 |            0 |             0 |     0 |              | https://www.youtube.com/watch?v=qFpYRF7O4pE#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D | Youtube  | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | Good King Wenceslas                | UC84nV7P2Ptlv7GKB-wQOBnA |        |              5 |

### playlists (805 rows)
|   id |   time_deleted | path                                                       | extractor_key   | title                                      | uploader                 | dl_config   | category   | extractor_playlist_id    |
|------|----------------|------------------------------------------------------------|-----------------|--------------------------------------------|--------------------------|-------------|------------|--------------------------|
|    1 |              0 | https://music.youtube.com/channel/UC84nV7P2Ptlv7GKB-wQOBnA | Youtube         | Uploads from John Fahey - Topic            | UC84nV7P2Ptlv7GKB-wQOBnA | {}          | Youtube    | UU84nV7P2Ptlv7GKB-wQOBnA |
|    2 |              0 | https://music.youtube.com/channel/UC7sXp-hm4lNsIo5MdceQriw | Youtube         | Uploads from Byron the Aquarius - Topic    | UC7sXp-hm4lNsIo5MdceQriw | {}          | Youtube    | UU7sXp-hm4lNsIo5MdceQriw |
|    3 |              0 | https://music.youtube.com/channel/UCbDrsvsiVVo8ITOzmq7IIjw | Youtube         | Uploads from Jan Hammer - Topic            | UCbDrsvsiVVo8ITOzmq7IIjw | {}          | Youtube    | UUbDrsvsiVVo8ITOzmq7IIjw |
|    4 |              0 | https://music.youtube.com/channel/UCqp5pFyqWp2BO-dSZC8wg2w | Youtube         | Uploads from Brendan Eder Ensemble - Topic | UCqp5pFyqWp2BO-dSZC8wg2w | {}          | Youtube    | UUqp5pFyqWp2BO-dSZC8wg2w |
|    5 |              0 | https://music.youtube.com/channel/UCXsfiixzUQNGe_zclENv45w | Youtube         | Uploads from Applefish - Topic             | UCXsfiixzUQNGe_zclENv45w | {}          | Youtube    | UUXsfiixzUQNGe_zclENv45w |


## free-yt-movies.tw.db
### media_new_1bd37e9c88f4 (0 rows)
| path   | size   | time_created   | duration   | play_count   | time_last_played   | language   | tags   | id   | ie_key   | title   | view_count   | width   | height   | fps   | average_rating   | live_status   | age_limit   | playlist_path   | uploader   | is_deleted   | is_downloaded   | time_uploaded   | time_modified   | time_deleted   | time_downloaded   |
|--------|--------|----------------|------------|--------------|---------------|------------|--------|------|----------|---------|--------------|---------|----------|-------|------------------|---------------|-------------|-----------------|------------|--------------|-----------------|-----------------|-----------------|----------------|-------------------|

### playlists_new_055877d7fff8 (0 rows)
| extractor_key   | title   | path   | uploader   | id   | yt_dlp_config   | dl_config   | is_deleted   | category   | profile   | time_deleted   |
|-----------------|---------|--------|------------|------|-----------------|-------------|--------------|------------|-----------|----------------|

### media (50929 rows)
|   id | path                        | size   | time_created   |   duration |   play_count |   time_last_played | language   | tags   | ie_key   | title                                                             | view_count   | width   | height   |   fps | average_rating   | live_status   | age_limit   | playlist_path                         | uploader   | is_deleted   | is_downloaded   | time_uploaded   | time_modified   |   time_deleted | time_downloaded   |   extractor_id |
|------|-----------------------------|--------|----------------|------------|--------------|---------------|------------|--------|----------|-------------------------------------------------------------------|--------------|---------|----------|-------|------------------|---------------|-------------|---------------------------------------|------------|--------------|-----------------|-----------------|-----------------|----------------|-------------------|----------------|
|    1 | https://vimeo.com/719255367 |        |                |          0 |            0 |             0 |            |        | Vimeo    | Fresh Cut Flowers (Tempestt Hazel + AZITA - CFA Media Mixer 2022) |              |         |          |     0 |                  |               |             | https://vimeo.com/chicagofilmarchives |            |              |                 |                 |                 |              0 |                   |              1 |
|    2 | https://vimeo.com/703054755 |        |                |          0 |            0 |             0 |            |        | Vimeo    | Three Goats and a Gruff (JoAnn Elam, ca. 1965)                    |              |         |          |     0 |                  |               |             | https://vimeo.com/chicagofilmarchives |            |              |                 |                 |                 |              0 |                   |              2 |
|    3 | https://vimeo.com/703054438 |        |                |          0 |            0 |             0 |            |        | Vimeo    | Beauty and the Beast (JoAnn Elam, ca. 1973)                       |              |         |          |     0 |                  |               |             | https://vimeo.com/chicagofilmarchives |            |              |                 |                 |                 |              0 |                   |              3 |
|    4 | https://vimeo.com/686318465 |        |                |          0 |            0 |             0 |            |        | Vimeo    | Mister E (Margaret Conneely, 1960)                                |              |         |          |     0 |                  |               |             | https://vimeo.com/chicagofilmarchives |            |              |                 |                 |                 |              0 |                   |              4 |
|    5 | https://vimeo.com/686057525 |        |                |          0 |            0 |             0 |            |        | Vimeo    | Games for Married Men (Ed Sinnott, ca. 1957)                      |              |         |          |     0 |                  |               |             | https://vimeo.com/chicagofilmarchives |            |              |                 |                 |                 |              0 |                   |              5 |

### playlists (2001 rows)
|   id | extractor_key   | title                  | path                                                | uploader   | yt_dlp_config   | dl_config   | is_deleted   | category    | profile   |   time_deleted |   extractor_playlist_id |
|------|-----------------|------------------------|-----------------------------------------------------|------------|-----------------|-------------|--------------|-------------|-----------|----------------|-------------------------|
|    1 | Vimeo           | Chicago Film Archives  | https://vimeo.com/chicagofilmarchives               |            |                 | {}          |              | Vimeo       | video     |              0 |                       1 |
|    2 | Vimeo           | Cristina Álvarez López | https://vimeo.com/cristinaalvarezlopez              |            |                 | {}          |              | Vimeo       | video     |              0 |                       2 |
|    3 | Vimeo           | Drew Morton            | https://vimeo.com/user15915571/videos               |            |                 | {}          |              | Vimeo       | video     |              0 |                       3 |
|    4 | Dailymotion     |                        | https://www.dailymotion.com/bosschannel/videos      |            |                 | {}          |              | Dailymotion | video     |              0 |                       4 |
|    5 | Dailymotion     |                        | https://www.dailymotion.com/XuanAurelio-9233/videos |            |                 |             |              |             |           |              0 |                       5 |


## mealtime.tw.db
### media_new_9b9ecf2884a9 (0 rows)
| path   | size   | time_created   | duration   | play_count   | time_last_played   | language   | tags   | id   | ie_key   | title   | view_count   | width   | height   | fps   | average_rating   | live_status   | age_limit   | playlist_path   | uploader   | is_deleted   | is_downloaded   | time_uploaded   | time_modified   | time_deleted   | time_downloaded   |
|--------|--------|----------------|------------|--------------|---------------|------------|--------|------|----------|---------|--------------|---------|----------|-------|------------------|---------------|-------------|-----------------|------------|--------------|-----------------|-----------------|-----------------|----------------|-------------------|

### playlists_new_5821dba35d87 (0 rows)
| extractor_key   | title   | path   | uploader   | id   | yt_dlp_config   | dl_config   | is_deleted   | category   | profile   | time_deleted   |
|-----------------|---------|--------|------------|------|-----------------|-------------|--------------|------------|-----------|----------------|

### media (218916 rows)
|   id | path                                            | size   | time_created   |   duration |   play_count |   time_last_played | language   | tags   | ie_key   | title                                   | view_count   | width   | height   |   fps | average_rating   | live_status   | age_limit   | playlist_path                         | uploader   | is_deleted   | is_downloaded   | time_uploaded   | time_modified   |   time_deleted | time_downloaded   |   extractor_id |
|------|-------------------------------------------------|--------|----------------|------------|--------------|---------------|------------|--------|----------|-----------------------------------------|--------------|---------|----------|-------|------------------|---------------|-------------|---------------------------------------|------------|--------------|-----------------|-----------------|-----------------|----------------|-------------------|----------------|
|    1 | https://vimeo.com/channels/staffpicks/741997426 |        |                |          0 |            0 |             0 |            |        | Vimeo    | INHERITANCE                             |              |         |          |     0 |                  |               |             | https://vimeo.com/channels/staffpicks |            |              |                 |                 |                 |              0 |                   |              1 |
|    2 | https://vimeo.com/channels/staffpicks/741185245 |        |                |          0 |            0 |             0 |            |        | Vimeo    | SOMEBODY&#039;S HERO                    |              |         |          |     0 |                  |               |             | https://vimeo.com/channels/staffpicks |            |              |                 |                 |                 |              0 |                   |              2 |
|    3 | https://vimeo.com/channels/staffpicks/740426857 |        |                |          0 |            0 |             0 |            |        | Vimeo    | FORD - SCARY FAST - DIRECTOR&#039;S CUT |              |         |          |     0 |                  |               |             | https://vimeo.com/channels/staffpicks |            |              |                 |                 |                 |              0 |                   |              3 |
|    4 | https://vimeo.com/channels/staffpicks/739573957 |        |                |          0 |            0 |             0 |            |        | Vimeo    | LA ESPERA                               |              |         |          |     0 |                  |               |             | https://vimeo.com/channels/staffpicks |            |              |                 |                 |                 |              0 |                   |              4 |
|    5 | https://vimeo.com/channels/staffpicks/740010189 |        |                |          0 |            0 |             0 |            |        | Vimeo    | In Tandem                               |              |         |          |     0 |                  |               |             | https://vimeo.com/channels/staffpicks |            |              |                 |                 |                 |              0 |                   |              5 |

### playlists (3033 rows)
|   id | extractor_key   | title                         | path                                             | uploader   | yt_dlp_config   | dl_config   | is_deleted   | category    | profile   |   time_deleted |   extractor_playlist_id |
|------|-----------------|-------------------------------|--------------------------------------------------|------------|-----------------|-------------|--------------|-------------|-----------|----------------|-------------------------|
|    1 | Vimeo           | Vimeo Staff Picks             | https://vimeo.com/channels/staffpicks            |            |                 | {}          |              | Vimeo       | video     |              0 |                       1 |
|    2 | Vimeo           | Kazak Productions             | https://vimeo.com/kazakproductions               |            |                 | {}          |              | Vimeo       | video     |              0 |                       2 |
|    3 | Vimeo           | Lori Felker                   | https://vimeo.com/lorifelker                     |            |                 | {}          |              | Vimeo       | video     |              0 |                       3 |
|    4 | Vimeo           | National Film Board of Canada | https://vimeo.com/thenfb                         |            |                 | {}          |              | Vimeo       | video     |              0 |                       4 |
|    5 | Dailymotion     |                               | https://www.dailymotion.com/31zmiua41d042/videos |            |                 | {}          |              | Dailymotion | video     |              0 |                       5 |


## music.tl.db
### media_new_5aad746447f6 (0 rows)
| path   | size   | time_created   | duration   | play_count   | time_last_played   | language   | tags   | id   | ie_key   | title   | view_count   | width   | height   | fps   | average_rating   | live_status   | age_limit   | playlist_path   | uploader   |
|--------|--------|----------------|------------|--------------|---------------|------------|--------|------|----------|---------|--------------|---------|----------|-------|------------------|---------------|-------------|-----------------|------------|

### playlists_new_4eba295563d7 (0 rows)
| extractor_key   | title   | path   | uploader   | id   | yt_dlp_config   |
|-----------------|---------|--------|------------|------|-----------------|

### media (402974 rows)
|   id | path                                                                                             | size   | time_created   |   duration |   play_count |   time_last_played | language   | tags   | ie_key   | title      | view_count   | width   | height   |   fps | average_rating   | live_status   | age_limit   | playlist_path                                                                | uploader                        |   extractor_id |
|------|--------------------------------------------------------------------------------------------------|--------|----------------|------------|--------------|---------------|------------|--------|----------|------------|--------------|---------|----------|-------|------------------|---------------|-------------|------------------------------------------------------------------------------|---------------------------------|----------------|
|    1 | https://www.youtube.com/watch?v=CVbzad1u6WM#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D |        |                |        333 |            1 |    1661362536 |            |        | Youtube  | متصوع      |              |         |          |     0 |                  |               |             | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 | عيضه المنهالي | Eida Al Menhali |              1 |
|    2 | https://www.youtube.com/watch?v=KQqDoJYILyI#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D |        |                |        206 |            0 |             0 |            |        | Youtube  | دلع بطره   |              |         |          |     0 |                  |               |             | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 | عيضه المنهالي | Eida Al Menhali |              2 |
|    3 | https://www.youtube.com/watch?v=i-sARO5hCe4#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D |        |                |        291 |            0 |             0 |            |        | Youtube  | مهما جرى   |              |         |          |     0 |                  |               |             | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 | عيضه المنهالي | Eida Al Menhali |              3 |
|    4 | https://www.youtube.com/watch?v=RLLzdkCybZ4#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D |        |                |        189 |            0 |             0 |            |        | Youtube  | أقول القول |              |         |          |     0 |                  |               |             | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 | عيضه المنهالي | Eida Al Menhali |              4 |
|    5 | https://www.youtube.com/watch?v=I1Yut6U2Bxg#__youtubedl_smuggle=%7B%22is_music_url%22%3A+true%7D |        |                |        257 |            0 |             0 |            |        | Youtube  | تدري أنته  |              |         |          |     0 |                  |               |             | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 | عيضه المنهالي | Eida Al Menhali |              5 |

### playlists (955 rows)
|   id | extractor_key   | title                        | path                                                                         | uploader                 | yt_dlp_config   |   extractor_playlist_id |
|------|-----------------|------------------------------|------------------------------------------------------------------------------|--------------------------|-----------------|-------------------------|
|    1 | Youtube         | Songs                        | https://music.youtube.com/browse/VLOLAK5uy_lPJFnUpePQo5O4uC7HOofm1Ucs1ssZYS8 |                          |                 |                       1 |
|    2 | Youtube         | Trending 20 Germany          | https://music.youtube.com/playlist?list=PL0sHkSjKd2rpxgOMD-vlUlIDqvQ5ChYJh   | UCK274iXLZhs8MFGLsncOyZQ |                 |                       2 |
|    3 | Youtube         | Top 100 Music Videos India   | https://music.youtube.com/playlist?list=PL4fGSI1pDJn40WjZ6utkIuj2rNg-7iGsq   | UCrKZcyOJVWnJ60zM1XWllNw |                 |                       3 |
|    4 | Youtube         | Top 100 Songs India          | https://music.youtube.com/playlist?list=PL4fGSI1pDJn4pTWyM3t61lOyZ6_4jcNOw   | UCrKZcyOJVWnJ60zM1XWllNw |                 |                       4 |
|    5 | Youtube         | Top 100 Music Videos Germany | https://music.youtube.com/playlist?list=PL4fGSI1pDJn4X-OicSCOy-dChXWdTgziQ   | UCrKZcyOJVWnJ60zM1XWllNw |                 |                       5 |


## podcasts.tl.db
### media (6889 rows)
|   id | path                                        | size   | time_created   |   duration |   play_count |   time_last_played | language   | tags   | ie_key   | title                                                                                      |   view_count | width   | height   |   fps | average_rating   | live_status   | age_limit   | playlist_path                                   | uploader   | is_deleted   | is_downloaded   | category   | profile   | dl_config   | error   | time_uploaded   | time_modified   |   time_deleted | time_downloaded   |   extractor_id |
|------|---------------------------------------------|--------|----------------|------------|--------------|---------------|------------|--------|----------|--------------------------------------------------------------------------------------------|--------------|---------|----------|-------|------------------|---------------|-------------|-------------------------------------------------|------------|--------------|-----------------|------------|-----------|-------------|---------|-----------------|-----------------|----------------|-------------------|----------------|
|    1 | https://www.youtube.com/watch?v=ChDYRIbkz_c |        |                |       3630 |            0 |             0 |            |        | Youtube  | Why We Get Resilience Wrong and The Surprising Science of Real Toughness | Talks at Google |         2554 |         |          |     0 |                  |               |             | https://www.youtube.com/c/talksatgoogle/videos/ |            |              |                 |            |           |             |         |                 |                 |              0 |                   |              1 |
|    2 | https://www.youtube.com/watch?v=LnEAIiVm9eg |        |                |       3630 |            0 |             0 |            |        | Youtube  | Deborah Liu | Take Back Your Power: 10 New Rules for Women at Work | Talks at Google       |         4310 |         |          |     0 |                  |               |             | https://www.youtube.com/c/talksatgoogle/videos/ |            |              |                 |            |           |             |         |                 |                 |              0 |                   |              2 |
|    3 | https://www.youtube.com/watch?v=Ci_vTJNTBjE |        |                |       2901 |            0 |             0 |            |        | Youtube  | Charles Clover | Rewilding the Sea: How to Save Our Oceans | Talks at Google               |         3516 |         |          |     0 |                  |               |             | https://www.youtube.com/c/talksatgoogle/videos/ |            |              |                 |            |           |             |         |                 |                 |              0 |                   |              3 |
|    4 | https://www.youtube.com/watch?v=VHYvPVv3VAY |        |                |       3598 |            0 |             0 |            |        | Youtube  | Sue Ann Pien, Rick Glassman and Albert Rutecki | As We See It | Talks at Google            |         3025 |         |          |     0 |                  |               |             | https://www.youtube.com/c/talksatgoogle/videos/ |            |              |                 |            |           |             |         |                 |                 |              0 |                   |              4 |
|    5 | https://www.youtube.com/watch?v=MfvCjc9X9_k |        |                |       2890 |            0 |             0 |            |        | Youtube  | Diane Kochilas | Greek Food & Blue Zone Ikaria | Talks at Google                           |         2383 |         |          |     0 |                  |               |             | https://www.youtube.com/c/talksatgoogle/videos/ |            |              |                 |            |           |             |         |                 |                 |              0 |                   |              5 |

### playlists (63 rows)
|   id | extractor_key   | title                         | path                                                            | uploader                 | dl_config   |   is_deleted | category      | profile   |   time_deleted |   extractor_playlist_id |
|------|-----------------|-------------------------------|-----------------------------------------------------------------|--------------------------|-------------|--------------|---------------|-----------|----------------|-------------------------|
|    1 | Youtube         | Talks at Google - Videos      | https://www.youtube.com/c/talksatgoogle/videos/                 | UCbmNph6atAoGfqLoCL_duAg | {}          |              | Youtube       | video     |              0 |                       1 |
|    2 | Youtube         | Vox - Videos                  | https://www.youtube.com/c/Vox/videos                            | UCLXo7UDZvByw2ixzpQCufnA | {}          |              | Youtube       | video     |              0 |                       2 |
|    3 | Youtube         | kuldeep - Videos              | https://www.youtube.com/channel/UCK0FaMBQ4CpEXNrK-wxsIIw/videos | UCK0FaMBQ4CpEXNrK-wxsIIw | {}          |              | Youtube       | video     |              0 |                       3 |
|    4 | Youtube         | Flibo_AVBooks - Videos        | https://www.youtube.com/c/Flibo_AVBooks/videos                  | UC5J7MFeKhAUI5mH3mfZc9pg | {}          |              | Youtube       | video     |              0 |                       4 |
|    5 | Generic         | No data from ydl.extract_info | http://feeds.wnyc.org/radiolab                                  |                          | {}          |            0 | Uncategorized | video     |              0 |                       5 |


## tabs.db
### media (217 rows)
|   id | path                                                                 | hostname       | frequency   | category   |   time_created |   time_last_played |   play_count |   is_deleted |   extractor_id |
|------|----------------------------------------------------------------------|----------------|-------------|------------|----------------|---------------|--------------|--------------|----------------|
|    1 | https://old.reddit.com/r/BuyItForLife/top/?sort=top&t=month          | old.reddit.com | monthly     | reddit     |     1661121297 |    1661113185 |            1 |            0 |              1 |
|    2 | https://old.reddit.com/r/AlternateAngles/top/?sort=top&t=month       | old.reddit.com | monthly     | reddit     |     1661121297 |    1661188080 |            1 |            0 |              2 |
|    3 | https://old.reddit.com/r/chemicalreactiongifs/top/?sort=top&t=month  | old.reddit.com | monthly     | reddit     |     1661121297 |    1661275834 |            1 |            0 |              3 |
|    4 | https://old.reddit.com/r/Colombia/top/?sort=top&t=month              | old.reddit.com | monthly     | reddit     |     1661121297 |             0 |            0 |            0 |              4 |
|    5 | https://old.reddit.com/r/confusing_perspective/top/?sort=top&t=month | old.reddit.com | monthly     | reddit     |     1661121297 |             0 |            0 |            0 |              5 |


